@@ -6,7 +6,7 @@ use Alien::Build::Plugin;
 use Text::ParseWords qw( shellwords );
 
 # ABSTRACT: Add dependencies to library and header search path
-our $VERSION = '0.99'; # VERSION
+our $VERSION = '1.00'; # VERSION
 
 
 has aliens => {};
@@ -92,24 +92,33 @@ sub init
 
       if($self->public_l)
       {
-        $build->runtime_prop->{$_} = join(' ', @{ $build->install_prop->{plugin_build_searchdep_libs} }) . ' ' . $build->runtime_prop->{$_}
+        $build->runtime_prop->{$_} = join(' ', _space_escape(@{ $build->install_prop->{plugin_build_searchdep_libs} })) . ' ' . $build->runtime_prop->{$_}
           for qw( libs libs_static );
       }
       
-      $build->runtime_prop->{$_} = join(' ', @{ $build->install_prop->{plugin_build_searchdep_ldflags} }) . ' ' . $build->runtime_prop->{$_}
+      $build->runtime_prop->{$_} = join(' ', _space_escape(@{ $build->install_prop->{plugin_build_searchdep_ldflags} })) . ' ' . $build->runtime_prop->{$_}
         for qw( libs libs_static );
 
       if($self->public_I)
       {
         $build->runtime_prop->{cflags}        = '' unless defined $build->runtime_prop->{cflags};
         $build->runtime_prop->{cflags_static} = '' unless defined $build->runtime_prop->{cflags_static};
-        $build->runtime_prop->{$_} = join(' ', @{ $build->install_prop->{plugin_build_searchdep_cflags} }) . ' ' . $build->runtime_prop->{$_}
+        $build->runtime_prop->{$_} = join(' ', _space_escape(@{ $build->install_prop->{plugin_build_searchdep_cflags} })) . ' ' . $build->runtime_prop->{$_}
           for qw( cflags cflags_static );
       }
     },
   );
 }
 
+sub _space_escape
+{
+  map {
+    my $str = $_;
+    $str =~ s{(\s)}{\\$1}g;
+    $str;
+  } @_;
+}
+
 1;
 
 __END__
@@ -124,7 +133,7 @@ Alien::Build::Plugin::Build::SearchDep - Add dependencies to library and header
 
 =head1 VERSION
 
-version 0.99
+version 1.00
 
 =head1 SYNOPSIS
 
